==> trading-api-wrappers-0.10.0.tar.gz: trading-api-wrappers-0.10.0/trading_api_wrappers/bitstamp/client_public.py <==
# local
from .server import BitstampServer
from ..base import Client


class BitstampPublic(Client):

    error_key = 'error'

    def __init__(self, timeout: int=30, retry=None):
        super().__init__(BitstampServer(), timeout, retry)

    def url_for(self, path, path_arg=None, version=2):
        if version == 1:
            url = f'{self.SERVER.URL}/{path}/'
        else:
            url = f'{self.SERVER.URL}/v{version}/{path}/'
        if path_arg:
            url = url % path_arg
        return url

    def ticker(self, currency_pair: str):
        """
        Returns ticker dictionary.
        """
        url = self.url_for('ticker/%s', currency_pair)
        return self.get(url)

    def ticker_hour(self, currency_pair: str):
        """
        Returns dictionary of the average ticker of the past hour.
        """
        url = self.url_for('ticker_hour/%s', currency_pair)
        return self.get(url)

    def order_book(self, currency_pair: str):
        """
        Returns dictionary with "bids" and "asks".

        Each is a list of open orders and each order is represented as a list
        of price and amount.
        """
        url = self.url_for('order_book/%s', currency_pair)
        return self.get(url)

    def transactions(self, currency_pair: str, time_interval: str=None):
        """
        Returns transactions for the last 'timedelta' seconds.

        Parameter time is specified by one of two values of TransRange class.
        """
        params = {'time': str(time_interval)} if time_interval else None
        url = self.url_for('transactions/%s', currency_pair)
        return self.get(url, params=params)

    def trading_pairs_info(self):
        """
        Returns list of dictionaries specifying details of each available
        trading pair:

            {
                'description':'Litecoin / U.S. dollar',
                'name':'LTC/USD',
                'url_symbol':'ltcusd',
                'trading':'Enabled',
                'minimum_order':'5.0 USD',
                'counter_decimals':2,
                'base_decimals':8
            },
        """
        url = self.url_for('trading-pairs-info')
        return self.get(url)

    def conversion_rate_usd_eur(self):
        """
        Returns simple dictionary:

            {'buy': 'buy conversion rate', 'sell': 'sell conversion rate'}
        """
        url = self.url_for('eur_usd', version=1)
        return self.get(url)

==> trading-api-wrappers-0.11.0.tar.gz: trading-api-wrappers-0.11.0/trading_api_wrappers/bitstamp/client_public.py <==
# local
from .server import BitstampServer
from ..base import Client


class BitstampPublic(Client):
    error_key = 'error'

    def __init__(self, timeout: int=30, retry=None):
        super().__init__(BitstampServer(), timeout, retry)

    @staticmethod
    def _endpoint_for(endpoint, version=2):
        # NOTE: Bitstamp urls MUST end with /
        if version == 1:
            return f'{endpoint}/'
        else:
            return f'v{version}/{endpoint}/'

    def ticker(self, currency_pair: str):
        """
        Returns ticker dictionary.
        """
        endpoint = self._endpoint_for(f'ticker/{currency_pair}')
        return self.get(endpoint)

    def ticker_hour(self, currency_pair: str):
        """
        Returns dictionary of the average ticker of the past hour.
        """
        endpoint = self._endpoint_for(f'ticker_hour/{currency_pair}')
        return self.get(endpoint)

    def order_book(self, currency_pair: str):
        """
        Returns dictionary with "bids" and "asks".

        Each is a list of open orders and each order is represented as a list
        of price and amount.
        """
        endpoint = self._endpoint_for(f'order_book/{currency_pair}')
        return self.get(endpoint)

    def transactions(self, currency_pair: str, time_interval: str=None):
        """
        Returns transactions for the last 'timedelta' seconds.

        Parameter time is specified by one of two values of TransRange class.
        """
        params = {'time': str(time_interval)} if time_interval else None
        endpoint = self._endpoint_for(f'transactions/{currency_pair}')
        return self.get(endpoint, params=params)

    def trading_pairs_info(self):
        """
        Returns list of dictionaries specifying details of each available
        trading pair:

            {
                'description':'Litecoin / U.S. dollar',
                'name':'LTC/USD',
                'url_symbol':'ltcusd',
                'trading':'Enabled',
                'minimum_order':'5.0 USD',
                'counter_decimals':2,
                'base_decimals':8
            },
        """
        return self.get(self._endpoint_for('trading-pairs-info'))

    def conversion_rate_usd_eur(self):
        """
        Returns simple dictionary:

            {'buy': 'buy conversion rate', 'sell': 'sell conversion rate'}
        """
        endpoint = self._endpoint_for('eur_usd', version=1)
        return self.get(endpoint)
